==> kubernetes-model-autoscaling-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/HorizontalPodAutoscalerListBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HorizontalPodAutoscalerListBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerList,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListBuilder>{
  public HorizontalPodAutoscalerListBuilder() {
    this(false);
  }
  public HorizontalPodAutoscalerListBuilder(java.lang.Boolean validationEnabled) {
    this(new HorizontalPodAutoscalerList(), validationEnabled);
  }
  public HorizontalPodAutoscalerListBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListFluent<?> fluent) {
    this(fluent, false);
  }
  public HorizontalPodAutoscalerListBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HorizontalPodAutoscalerList(), validationEnabled);
  }
  public HorizontalPodAutoscalerListBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerList instance) {
    this(fluent, instance, false);
  }
  public HorizontalPodAutoscalerListBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public HorizontalPodAutoscalerListBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerList instance) {
    this(instance,false);
  }
  public HorizontalPodAutoscalerListBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerList build() {
    HorizontalPodAutoscalerList buildable = new HorizontalPodAutoscalerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HorizontalPodAutoscalerListBuilder that = (HorizontalPodAutoscalerListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-autoscaling-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/HorizontalPodAutoscalerListBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HorizontalPodAutoscalerListBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerList,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListBuilder>{
  public HorizontalPodAutoscalerListBuilder() {
    this(false);
  }
  public HorizontalPodAutoscalerListBuilder(java.lang.Boolean validationEnabled) {
    this(new HorizontalPodAutoscalerList(), validationEnabled);
  }
  public HorizontalPodAutoscalerListBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListFluent<?> fluent) {
    this(fluent, false);
  }
  public HorizontalPodAutoscalerListBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HorizontalPodAutoscalerList(), validationEnabled);
  }
  public HorizontalPodAutoscalerListBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerList instance) {
    this(fluent, instance, false);
  }
  public HorizontalPodAutoscalerListBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public HorizontalPodAutoscalerListBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerList instance) {
    this(instance,false);
  }
  public HorizontalPodAutoscalerListBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerList build() {
    HorizontalPodAutoscalerList buildable = new HorizontalPodAutoscalerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HorizontalPodAutoscalerListBuilder that = (HorizontalPodAutoscalerListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
